@@ -854,9 +854,7 @@ class TestDurations(object):
         result = testdir.runpytest("--durations=2")
         assert result.ret == 0
         lines = result.stdout.get_lines_after("*slowest*durations*")
-        # account for the "deprecated python version" header
-        index = 2 if sys.version_info[:2] > (3, 4) else 6
-        assert "4 passed" in lines[index]
+        assert "4 passed" in lines[2]
 
     def test_calls_showall(self, testdir):
         testdir.makepyfile(self.source)
@@ -969,6 +967,20 @@ def test_import_plugin_unicode_name(testdir):
     assert r.ret == 0
 
 
+def test_pytest_plugins_as_module(testdir):
+    """Do not raise an error if pytest_plugins attribute is a module (#3899)"""
+    testdir.makepyfile(
+        **{
+            "__init__.py": "",
+            "pytest_plugins.py": "",
+            "conftest.py": "from . import pytest_plugins",
+            "test_foo.py": "def test(): pass",
+        }
+    )
+    result = testdir.runpytest()
+    result.stdout.fnmatch_lines("* 1 passed in *")
+
+
 def test_deferred_hook_checking(testdir):
     """
     Check hooks as late as possible (#1821).
