@@ -37,7 +37,7 @@ def test_code_with_class():
     class A(object):
         pass
 
-    pytest.raises(TypeError, "_pytest._code.Code(A)")
+    pytest.raises(TypeError, _pytest._code.Code, A)
 
 
 def x():
@@ -169,7 +169,7 @@ class TestExceptionInfo(object):
             else:
                 assert False
         except AssertionError:
-            exci = _pytest._code.ExceptionInfo()
+            exci = _pytest._code.ExceptionInfo.from_current()
         assert exci.getrepr()
 
 
@@ -181,7 +181,7 @@ class TestTracebackEntry(object):
             else:
                 assert False
         except AssertionError:
-            exci = _pytest._code.ExceptionInfo()
+            exci = _pytest._code.ExceptionInfo.from_current()
         entry = exci.traceback[0]
         source = entry.getsource()
         assert len(source) == 6
