@@ -240,9 +240,6 @@ class TestClass(object):
         assert result.ret == EXIT_NOTESTSCOLLECTED
 
 
-@pytest.mark.filterwarnings(
-    "ignore:usage of Generator.Function is deprecated, please use pytest.Function instead"
-)
 class TestFunction(object):
     def test_getmodulecollector(self, testdir):
         item = testdir.getitem("def test_func(): pass")
@@ -963,7 +960,7 @@ class TestTracebackCutting(object):
 
     def test_filter_traceback_generated_code(self):
         """test that filter_traceback() works with the fact that
-        py.code.Code.path attribute might return an str object.
+        _pytest._code.code.Code.path attribute might return an str object.
         In this case, one of the entries on the traceback was produced by
         dynamically generated code.
         See: https://bitbucket.org/pytest-dev/py/issues/71
@@ -984,7 +981,7 @@ class TestTracebackCutting(object):
 
     def test_filter_traceback_path_no_longer_valid(self, testdir):
         """test that filter_traceback() works with the fact that
-        py.code.Code.path attribute might return an str object.
+        _pytest._code.code.Code.path attribute might return an str object.
         In this case, one of the files in the traceback no longer exists.
         This fixes #1133.
         """
