@@ -127,6 +127,17 @@ def test_runresult_assertion_on_xpassed(testdir):
     assert result.ret == 0
 
 
+def test_runresult_repr():
+    from _pytest.pytester import RunResult
+
+    assert (
+        repr(
+            RunResult(ret="ret", outlines=[""], errlines=["some", "errors"], duration=1)
+        )
+        == "<RunResult ret='ret' len(stdout.lines)=1 len(stderr.lines)=2 duration=1.00s>"
+    )
+
+
 def test_xpassed_with_strict_is_considered_a_failure(testdir):
     testdir.makepyfile(
         """
