@@ -770,6 +770,7 @@ def test_skip_reasons_folding():
 
     # ev3 might be a collection report
     ev3 = X()
+    ev3.when = "collect"
     ev3.longrepr = longrepr
     ev3.skipped = True
 
@@ -1202,6 +1203,6 @@ def test_summary_list_after_errors(testdir):
         [
             "=* FAILURES *=",
             "*= short test summary info =*",
-            "FAIL test_summary_list_after_errors.py::test_fail",
+            "FAILED test_summary_list_after_errors.py::test_fail",
         ]
     )
